@@ -5,6 +5,7 @@ import glob
 import lxml
 import lxml.etree
 import importlib.metadata
+import importlib.resources
 __package__ = importlib.metadata.metadata("isaac-xml-validator").get("name")
 __version__ = importlib.metadata.version("isaac-xml-validator")
 
@@ -55,6 +56,22 @@ file_ignore_list = [
     "seedmenu.xml",
 ]
 
+# ~~~~~~~~~~~~ Special conditions ~~~~~~~~~~~~
+
+def entity2_auto_increment_check(root, file_path):
+    err_count = 0
+    for child in list(root):
+        if child.tag == "entity" and child.get("id") is not None and child.get("variant") is None:
+            if (child.get("id") == "5" or child.get("id") == "1000"):
+                print_err(f"{file_path}:line {child.sourceline}: Element '{child.tag}': Variant attribute is missing. This is not allowed for IDs equal 5 or 1000!")
+                err_count +=1
+    return err_count
+
+special_conditions = {
+    "entities2.xml": [entity2_auto_increment_check]
+}
+
+# ~~~~~~~~~~~~ Code ~~~~~~~~~~~~
 
 def clear_isaac_refs_recursive(node):
     for child in list(node):
@@ -121,20 +138,21 @@ def main():
 
         # Parse the XML file using our XSD file.
         xml_errors = parse_isaac_xml_file(file_path, xsd_path)
-        if xml_errors is None:
-            continue
-
-        for error in xml_errors:
-            print_err(
-                error.filename
-                + ":line "
-                + str(error.line)
-                + ":col "
-                + str(error.column)
-                + ": "
-                + error.message
-            )
+        if xml_errors is not None:
+            for error in xml_errors:
+                print_err(
+                    error.filename
+                    + ":line "
+                    + str(error.line)
+                    + ":col "
+                    + str(error.column)
+                    + ": "
+                    + error.message
+                )
         error_count += len(xml_errors)
+
+        error_count += evaluate_special_conditions(file_path)
+
         if error_count > 0:
             printf(f"---- End errors for file: {file_path}")
 
@@ -149,6 +167,19 @@ def main():
     else:
         print_ok("No errors found")
 
+def evaluate_special_conditions(xml_file_path: str):
+    """Checks file specific conditions that could not be evaluated with XSD schemas"""
+    try:
+        errorCount = 0
+        xml_doc = lxml.etree.parse(xml_file_path)
+        if os.path.basename(xml_file_path) in special_conditions:
+            for func in special_conditions[os.path.basename(xml_file_path)]:
+                errorCount += func(xml_doc.getroot(), xml_file_path)
+        return errorCount
+    except Exception as err:
+        print_err(err)
+        return 1
+
 
 def parse_isaac_xml_file(xml_file_path: str, xsd_file_path: str):
     """Returns an array of errors or `None` if validation succeeded."""
@@ -170,11 +201,30 @@ def parse_isaac_xml_file(xml_file_path: str, xsd_file_path: str):
         xml_schema = lxml.etree.XMLSchema(xml_schema_file_doc)
         xml_doc = lxml.etree.parse(xml_file_path)
         xml_schema.validate(xml_doc)
+
         return xml_schema.error_log
 
     except Exception as err:
         print_err(err)
         return xml_schema.error_log
 
+def read_github_env_vars():
+    global root_folder, expected_error_count, recursive
+    printf("Evaluate settings:")
+
+    if "INPUT_ROOTFOLDER" in os.environ:
+        root_folder = os.environ["INPUT_ROOTFOLDER"]
+    printf("\tRoot folder: ", root_folder)
+
+    if "INPUT_RECURSIVE" in os.environ:
+        recursive = bool(os.environ["INPUT_RECURSIVE"])
+    printf("\tRecursive: ", recursive)
+
+    if "INPUT_EXPECTEDERRORCOUNT" in os.environ:
+        expected_error_count = int(os.environ["INPUT_EXPECTEDERRORCOUNT"])
+    printf("\tExpected Error Count: ", expected_error_count)
+
+
 if __name__ == "__main__":
+    read_github_env_vars()
     main()
